// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KF6KirigamiActionCollection_VERSION_H
#define KF6KirigamiActionCollection_VERSION_H

#define KF6KirigamiActionCollection_VERSION_STRING "1.0.2"
#define KF6KirigamiActionCollection_VERSION_MAJOR 1
#define KF6KirigamiActionCollection_VERSION_MINOR 0
#define KF6KirigamiActionCollection_VERSION_PATCH 2
#define KF6KirigamiActionCollection_VERSION ((1<<16)|(0<<8)|(2))

#endif
