
#ifndef KIRIGAMIACTIONCOLLECTION_EXPORT_H
#define KIRIGAMIACTIONCOLLECTION_EXPORT_H

#ifdef KIRIGAMIACTIONCOLLECTION_STATIC_DEFINE
#  define KIRIGAMIACTIONCOLLECTION_EXPORT
#  define KIRIGAMIACTIONCOLLECTION_NO_EXPORT
#else
#  ifndef KIRIGAMIACTIONCOLLECTION_EXPORT
#    ifdef KirigamiActionCollection_EXPORTS
        /* We are building this library */
#      define KIRIGAMIACTIONCOLLECTION_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIRIGAMIACTIONCOLLECTION_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIRIGAMIACTIONCOLLECTION_NO_EXPORT
#    define KIRIGAMIACTIONCOLLECTION_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED
#  define KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED_EXPORT KIRIGAMIACTIONCOLLECTION_EXPORT KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED
#endif

#ifndef KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED_NO_EXPORT
#  define KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED_NO_EXPORT KIRIGAMIACTIONCOLLECTION_NO_EXPORT KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED
#    define KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED
#  endif
#endif

#define KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED) && !defined(KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KAC_NO_DEPRECATED
#    define KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED
#  elif defined(KAC_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT KAC_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KAC_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT KAC_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED_WARNINGS) && !defined(KIRIGAMIACTIONCOLLECTION_DEPRECATED_WARNINGS_SINCE)
#  ifdef KAC_NO_DEPRECATED_WARNINGS
#    define KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED_WARNINGS
#  elif defined(KAC_DEPRECATED_WARNINGS_SINCE)
#    define KIRIGAMIACTIONCOLLECTION_DEPRECATED_WARNINGS_SINCE KAC_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KIRIGAMIACTIONCOLLECTION_DEPRECATED_WARNINGS_SINCE) && defined(KAC_DEPRECATED_WARNINGS_SINCE)
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED_WARNINGS_SINCE KAC_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED)
#  undef KIRIGAMIACTIONCOLLECTION_DEPRECATED
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED_EXPORT KIRIGAMIACTIONCOLLECTION_EXPORT
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED_NO_EXPORT KIRIGAMIACTIONCOLLECTION_NO_EXPORT
#elif defined(KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED_WARNINGS)
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED_EXPORT KIRIGAMIACTIONCOLLECTION_EXPORT
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED_NO_EXPORT KIRIGAMIACTIONCOLLECTION_NO_EXPORT
#else
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED_EXPORT KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED_NO_EXPORT KIRIGAMIACTIONCOLLECTION_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIRIGAMIACTIONCOLLECTION_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIRIGAMIACTIONCOLLECTION_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED
#  define KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10002
#endif
#ifdef KIRIGAMIACTIONCOLLECTION_NO_DEPRECATED_WARNINGS
#  define KIRIGAMIACTIONCOLLECTION_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIRIGAMIACTIONCOLLECTION_DEPRECATED_WARNINGS_SINCE
#  ifdef KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIRIGAMIACTIONCOLLECTION_DEPRECATED_WARNINGS_SINCE KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIRIGAMIACTIONCOLLECTION_DEPRECATED_WARNINGS_SINCE 0x10002
#  endif
#endif

#ifndef KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KIRIGAMIACTIONCOLLECTION_DEPRECATED
#  define KIRIGAMIACTIONCOLLECTION_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIRIGAMIACTIONCOLLECTION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIRIGAMIACTIONCOLLECTION_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KIRIGAMIACTIONCOLLECTION_EXPORT_H */
